==> haskell-monad-control-1.0.1.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-monad-control.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-control
version: 1.0.1.0
id: monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
key: monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
license: BSD3
copyright: (c) 2011 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/monad-control
synopsis: Lift control operations, like exception catching, through monad transformers
description:
    This package defines the type class @MonadBaseControl@, a subset of
    @MonadBase@ into which generic control operations such as @catch@ can be
    lifted from @IO@ or any other base monad. Instances are based on monad
    transformers in @MonadTransControl@, which includes all standard monad
    transformers in the @transformers@ library except @ContT@.
    .
    See the @lifted-base@ package which uses @monad-control@ to lift @IO@
    operations from the @base@ library (like @catch@ or @bracket@) into any monad
    that is an instance of @MonadBase@ or @MonadBaseControl@.
    .
    Note that this package is a rewrite of Anders Kaseorg'\''s @monad-peel@
    library. The main difference is that this package provides CPS style operators
    and exploits the @RankNTypes@ and @TypeFamilies@ language extensions to
    simplify and speedup most definitions.
category: Control
author: Bas van Dijk, Anders Kaseorg
exposed: True
exposed-modules:
    Control.Monad.Trans.Control
abi: 0b9ad9f5a0d5695270300703b79dd681
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/monad-control-1.0.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/monad-control-1.0.1.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/monad-control-1.0.1.0
hs-libraries: HSmonad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
depends:
    base-4.9.0.0 stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    transformers-0.5.2.0 transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-monad-control/html/monad-control.haddock
haddock-html: /usr/share/doc/haskell-monad-control/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-control-1.0.2.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-monad-control.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-control
version: 1.0.2.1
id: monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
key: monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
license: BSD3
copyright: (c) 2011 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/monad-control
synopsis: Lift control operations, like exception catching, through monad transformers
description:
    This package defines the type class @MonadBaseControl@, a subset of
    @MonadBase@ into which generic control operations such as @catch@ can be
    lifted from @IO@ or any other base monad. Instances are based on monad
    transformers in @MonadTransControl@, which includes all standard monad
    transformers in the @transformers@ library except @ContT@.
    .
    See the <http://hackage.haskell.org/package/lifted-base lifted-base>
    package which uses @monad-control@ to lift @IO@
    operations from the @base@ library (like @catch@ or @bracket@) into any monad
    that is an instance of @MonadBase@ or @MonadBaseControl@.
    .
    Note that this package is a rewrite of Anders Kaseorg'\''s @monad-peel@
    library. The main difference is that this package provides CPS style operators
    and exploits the @RankNTypes@ and @TypeFamilies@ language extensions to
    simplify and speedup most definitions.
category: Control
author: Bas van Dijk, Anders Kaseorg
exposed: True
exposed-modules:
    Control.Monad.Trans.Control
abi: 3129e33f3914b863c768a35fc130feae
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/monad-control-1.0.2.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/monad-control-1.0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/monad-control-1.0.2.1
hs-libraries: HSmonad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
depends:
    base-4.9.1.0 stm-2.4.4.1-iSYwp3RMY11sHCifJ3gtR transformers-0.5.2.0
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
haddock-interfaces: /usr/share/doc/haskell-monad-control/html/monad-control.haddock
haddock-html: /usr/share/doc/haskell-monad-control/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
